#!/usr/bin/env node
"use strict";

var _command = require("@oclif/command");

var _errors = require("@oclif/errors");

var _createSplunkEventsStream = require("./splunk/createSplunkEventsStream");

var _getSplunk = require("./splunk/getSplunk");

class PinoSplunkEvents extends _command.Command {
  static description = 'Log events to splunk';
  static flags = {
    endpoint: _command.flags.string({
      description: 'Endpoint of your Splunk server',
      required: true
    }),
    token: _command.flags.string({
      description: 'Token used to authenticate with the Splunk server',
      required: true
    }),
    debug: _command.flags.boolean({
      description: 'Enable debugging mode',
      default: false
    })
  };

  async run() {
    const parsed = this.parse(PinoSplunkEvents);
    const splunk = (0, _getSplunk.getSplunk)(parsed.flags);
    const writeStream = (0, _createSplunkEventsStream.createSplunkEventsStream)(splunk);
    process.stdin.pipe(process.stdout);
    process.stdin.pipe(writeStream);
  }

}

PinoSplunkEvents.run().then(null, _errors.handle);
//# sourceMappingURL=cli.js.map